|Travis|_ |Appveyor|_ |Codecov|_ |CircleCI|_ |Documentation|_ |LanguageGrade|_ |License|_

.. |Travis| image:: https://travis-ci.com/j-bac/elpigraph-python.svg?branch=master
.. _Travis: https://travis-ci.com/j-bac/elpigraph-python
.. |Appveyor| image:: https://ci.appveyor.com/api/projects/status/tvumlfad69g6ap3u/branch/master?svg=true
.. _Appveyor: https://ci.appveyor.com/project/j-bac/elpigraph-python/branch/master
.. |Codecov| image:: https://codecov.io/gh/j-bac/elpigraph-python/badge.svg?branch=master&service=github
.. _Codecov: https://codecov.io/gh/j-bac/elpigraph-python/
.. |CircleCI| image:: https://circleci.com/gh/j-bac/elpigraph-python/tree/master.svg?style=shield
.. _CircleCI: https://circleci.com/gh/j-bac/elpigraph-python/tree/master
.. |Documentation| image:: https://readthedocs.org/projects/elpigraph-python/badge/?version=latest
.. _Documentation: https://elpigraph-python.readthedocs.io
.. |LanguageGrade| image:: https://img.shields.io/lgtm/grade/python/g/j-bac/elpigraph-python.svg?logo=lgtm&logoWidth=18
.. _LanguageGrade: https://lgtm.com/projects/g/j-bac/elpigraph-python/context:python
.. |License| image:: https://img.shields.io/github/license/j-bac/elpigraph-python.svg
.. _License: https://github.com/j-bac/elpigraph-python/blob/master/LICENSE

elpigraph-python - Intrinsic dimension estimation in Python
===========================================================

**elpigraph-python** is a Python module to fit principal graphs to data.

What are principal graphs ?
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

Principal graph algorithms fit a graph that passes in the middle of the data point cloud.

Organization of `elpigraph-python`
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

`elpigraph-python` provides principal graph functions directly in the main module, and two submodules `plot` and `utils` contain utility functions.

Support
^^^^^^^
Feel free to report an `issue <https://github.com/j-bac/elpigraph-python/issues/new/choose>`_

.. toctree::
   :maxdepth: 1
   :hidden:
   :caption: Main

   installation
   quick_start
   api
   release_notes
   references
   contributing

.. toctree::
   :caption: Tutorials
   :maxdepth: 1
   :hidden:

   basics